#ifndef MODEL_H
#define MODEL_H

#include <QObject>
#include "tagger.h"

Tag readTags(const QString &fileName);

class Model : public QObject
{
    Q_OBJECT
public:
    explicit Model(QObject *parent = 0);

    void selectAll();
    bool hasSelection() const;
    int selectionSize() const {return indexes.size();}
    bool selectionSaved() const;
    QList<int> selection() const {return indexes;}
    Tag &fileAt(int index);
    Tag &fileAtSelection(int index);
    QList<Tag> selectedFiles();
    void setSelection(const QList<int> &selection);

    bool isEmpty() const;

    bool allSaved() const;
    bool allSelectedFilesAreMP3() const;
    bool imagesAreSame() const;
    int size() const;
    int totalLength() const;

    QList<Tag> addFiles(const QStringList &filesToAdd);
    void       addFiles(const QList<Tag> &tagsToAdd);
    void delFiles();
    void save(bool silently=false);
    bool saveAt(int index);
    void forceSelectionToSave();
    void move(bool up);
    void setTags(const QList<int> &inds,const QList<Tag> &newTags);
    void setRow(int tagID, const QString &newValue);
    void setRow(const QString &stringID, const QString &newValue);
    void setTag(int index, int tagID, const QString &newValue);
    void setTag(int index, const QString &tagID, const QString &newValue);
    void removeAllTags();
    void removeUserTags();
    void removeImage();

    QStringList tagsByPattern(int tagID, const QString &newValue);
    void rereadTags(bool all, bool force);

    QStringList values(int tagID) const;
    QStringList values(const QString &tagID) const;
    QString value(int index, int tagID) const;
    QString value(int index, const QString &tagID) const;
    /**
     * Returns file names list of selected files
     */
    QStringList fileNames() const;
    QStringList userTagsIds() const;

    /**
     * Renames selection with newFileNames and returns not renamed files names
     * message will be updated accordingly
     */
    void rename(const QStringList &newFileNames);

    void setImage(const CoverImage &img);
    void setImageDescription(const QString &description);
    void setImageType(int type);
    bool writeImage(QString dirName);

    bool setNewImage(int ind,const CoverImage &image);
    void setOldImage(int ind,const CoverImage &image, bool status);
signals:
    void fileChanged(int,bool); //emits when tag save state changed
    void fileChanged(int,const Tag&,const QList<int>&); //emits when whole file needs updating
    void fileNameChanged(int, const QString newFileName);
    void imageChanged(int index, bool imageEmpty);
    void message(int type, const QString &text);
private:
    void saveFiles(const QList<int> &toSave, bool silently=false);
    bool newTagsEqual(const QStringList &newTags, int tagID, const QString &stringID);

    QList<int> indexes;
    QList<Tag> tags;
};

#endif // MODEL_H
